/*
 * Code for class XML_PARSER_FACTORY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm544.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XML_PARSER_FACTORY}.new_parser */
EIF_REFERENCE F597_10256 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("new_parser", 596, Current, 0, 0, 9239);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) F597_10257(Current);
}

/* {XML_PARSER_FACTORY}.new_standard_parser */
EIF_REFERENCE F597_10257 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("new_standard_parser", 596, Current, 0, 0, 9240);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1335, 0x00).id, 1335, _OBJSIZ_5_3_0_2_0_0_0_0_);
	F1336_19490(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) tr1;
}

void EIF_Minit544 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
